#!/bin/bash

# 1. (manual patching of broken SVD)
# 2. Form to get separate files
# 3. SVD -> .rs
# 4. Patch away warning for `private_no_mangle_statics`
#  as it is default now
# 5. Format code using `cargo fmt`
SVDFILE='LPC43xx_43Sxx_M0APP.svd'
LIBFILE='src/lib.rs'
LIBFILE='src/lib.rs'

cmd_exists() {
	if ! [ -x "$(command -v "$1")" ]; then
		echo "Could not find the \"$1\" command, make sure that it exists and is reachable."
		exit 1
	fi
}

exists() {
	if [ ! -f "$1" ]; then
		echo "Could not find \"$1\", make sure that it exists and is reachable."
		exit 1
	fi
}

echo "Building rust sources..."
    exists "$SVDFILE"
    cmd_exists "svd2rust"
    svd2rust -i "$SVDFILE" --nightly
echo "Done."

if [ -d "src" ]; then
    rm -rf "src/*"
else
    mkdir "src"
fi

echo "Moving libfile into target src directory"
mv lib.rs src/lib.rs

echo "Breaking code into multiple files..."
    cmd_exists "form"
    form -i "$LIBFILE" -o "src/"
    exists "$LIBFILE"
echo "Done."

 
echo "Formatting code..."
    cmd_exists "cargo"
    cargo fmt
echo "Done."

echo "Patching out warning..."
    cmd_exists "sed"
    exists "$LIBFILE"
    sed -i '1s;^;\#\![allow(non_snake_case)]\n;' "$LIBFILE"
echo "Done."

echo "Building code..."
    cmd_exists "cargo"
    cargo build
echo "Done."
