#[doc = r"Register block"]
#[repr(C)]
pub struct RegisterBlock {
    #[doc = "0x00 - MAC configuration register"]
    pub mac_config: MAC_CONFIG,
    #[doc = "0x04 - MAC frame filter"]
    pub mac_frame_filter: MAC_FRAME_FILTER,
    #[doc = "0x08 - Hash table high register"]
    pub mac_hashtable_high: MAC_HASHTABLE_HIGH,
    #[doc = "0x0c - Hash table low register"]
    pub mac_hashtable_low: MAC_HASHTABLE_LOW,
    #[doc = "0x10 - MII address register"]
    pub mac_mii_addr: MAC_MII_ADDR,
    #[doc = "0x14 - MII data register"]
    pub mac_mii_data: MAC_MII_DATA,
    #[doc = "0x18 - Flow control register"]
    pub mac_flow_ctrl: MAC_FLOW_CTRL,
    #[doc = "0x1c - VLAN tag register"]
    pub mac_vlan_tag: MAC_VLAN_TAG,
    _reserved8: [u8; 4usize],
    #[doc = "0x24 - Debug register"]
    pub mac_debug: MAC_DEBUG,
    #[doc = "0x28 - Remote wake-up frame filter"]
    pub mac_rwake_frflt: MAC_RWAKE_FRFLT,
    #[doc = "0x2c - PMT control and status"]
    pub mac_pmt_ctrl_stat: MAC_PMT_CTRL_STAT,
    _reserved11: [u8; 8usize],
    #[doc = "0x38 - Interrupt status register"]
    pub mac_intr: MAC_INTR,
    #[doc = "0x3c - Interrupt mask register"]
    pub mac_intr_mask: MAC_INTR_MASK,
    #[doc = "0x40 - MAC address 0 high register"]
    pub mac_addr0_high: MAC_ADDR0_HIGH,
    #[doc = "0x44 - MAC address 0 low register"]
    pub mac_addr0_low: MAC_ADDR0_LOW,
    _reserved15: [u8; 1720usize],
    #[doc = "0x700 - Time stamp control register"]
    pub mac_timestp_ctrl: MAC_TIMESTP_CTRL,
    #[doc = "0x704 - Sub-second increment register"]
    pub subsecond_incr: SUBSECOND_INCR,
    #[doc = "0x708 - System time seconds register"]
    pub seconds: SECONDS,
    #[doc = "0x70c - System time nanoseconds register"]
    pub nanoseconds: NANOSECONDS,
    #[doc = "0x710 - System time seconds update register"]
    pub secondsupdate: SECONDSUPDATE,
    #[doc = "0x714 - System time nanoseconds update register"]
    pub nanosecondsupdate: NANOSECONDSUPDATE,
    #[doc = "0x718 - Time stamp addend register"]
    pub addend: ADDEND,
    #[doc = "0x71c - Target time seconds register"]
    pub targetseconds: TARGETSECONDS,
    #[doc = "0x720 - Target time nanoseconds register"]
    pub targetnanoseconds: TARGETNANOSECONDS,
    #[doc = "0x724 - System time higher word seconds register"]
    pub highword: HIGHWORD,
    #[doc = "0x728 - Time stamp status register"]
    pub timestampstat: TIMESTAMPSTAT,
    _reserved26: [u8; 2260usize],
    #[doc = "0x1000 - Bus Mode Register"]
    pub dma_bus_mode: DMA_BUS_MODE,
    #[doc = "0x1004 - Transmit poll demand register"]
    pub dma_trans_poll_demand: DMA_TRANS_POLL_DEMAND,
    #[doc = "0x1008 - Receive poll demand register"]
    pub dma_rec_poll_demand: DMA_REC_POLL_DEMAND,
    #[doc = "0x100c - Receive descriptor list address register"]
    pub dma_rec_des_addr: DMA_REC_DES_ADDR,
    #[doc = "0x1010 - Transmit descriptor list address register"]
    pub dma_trans_des_addr: DMA_TRANS_DES_ADDR,
    #[doc = "0x1014 - Status register"]
    pub dma_stat: DMA_STAT,
    #[doc = "0x1018 - Operation mode register"]
    pub dma_op_mode: DMA_OP_MODE,
    #[doc = "0x101c - Interrupt enable register"]
    pub dma_int_en: DMA_INT_EN,
    #[doc = "0x1020 - Missed frame and buffer overflow register"]
    pub dma_mfrm_bufof: DMA_MFRM_BUFOF,
    #[doc = "0x1024 - Receive interrupt watchdog timer register"]
    pub dma_rec_int_wdt: DMA_REC_INT_WDT,
    _reserved36: [u8; 32usize],
    #[doc = "0x1048 - Current host transmit descriptor register"]
    pub dma_curhost_trans_des: DMA_CURHOST_TRANS_DES,
    #[doc = "0x104c - Current host receive descriptor register"]
    pub dma_curhost_rec_des: DMA_CURHOST_REC_DES,
    #[doc = "0x1050 - Current host transmit buffer address register"]
    pub dma_curhost_trans_buf: DMA_CURHOST_TRANS_BUF,
    #[doc = "0x1054 - Current host receive buffer address register"]
    pub dma_curhost_rec_buf: DMA_CURHOST_REC_BUF,
}
#[doc = "MAC configuration register\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [mac_config](mac_config) module"]
pub type MAC_CONFIG = crate::Reg<u32, _MAC_CONFIG>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _MAC_CONFIG;
#[doc = "`read()` method returns [mac_config::R](mac_config::R) reader structure"]
impl crate::Readable for MAC_CONFIG {}
#[doc = "`write(|w| ..)` method takes [mac_config::W](mac_config::W) writer structure"]
impl crate::Writable for MAC_CONFIG {}
#[doc = "MAC configuration register"]
pub mod mac_config;
#[doc = "MAC frame filter\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [mac_frame_filter](mac_frame_filter) module"]
pub type MAC_FRAME_FILTER = crate::Reg<u32, _MAC_FRAME_FILTER>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _MAC_FRAME_FILTER;
#[doc = "`read()` method returns [mac_frame_filter::R](mac_frame_filter::R) reader structure"]
impl crate::Readable for MAC_FRAME_FILTER {}
#[doc = "`write(|w| ..)` method takes [mac_frame_filter::W](mac_frame_filter::W) writer structure"]
impl crate::Writable for MAC_FRAME_FILTER {}
#[doc = "MAC frame filter"]
pub mod mac_frame_filter;
#[doc = "Hash table high register\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [mac_hashtable_high](mac_hashtable_high) module"]
pub type MAC_HASHTABLE_HIGH = crate::Reg<u32, _MAC_HASHTABLE_HIGH>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _MAC_HASHTABLE_HIGH;
#[doc = "`read()` method returns [mac_hashtable_high::R](mac_hashtable_high::R) reader structure"]
impl crate::Readable for MAC_HASHTABLE_HIGH {}
#[doc = "`write(|w| ..)` method takes [mac_hashtable_high::W](mac_hashtable_high::W) writer structure"]
impl crate::Writable for MAC_HASHTABLE_HIGH {}
#[doc = "Hash table high register"]
pub mod mac_hashtable_high;
#[doc = "Hash table low register\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [mac_hashtable_low](mac_hashtable_low) module"]
pub type MAC_HASHTABLE_LOW = crate::Reg<u32, _MAC_HASHTABLE_LOW>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _MAC_HASHTABLE_LOW;
#[doc = "`read()` method returns [mac_hashtable_low::R](mac_hashtable_low::R) reader structure"]
impl crate::Readable for MAC_HASHTABLE_LOW {}
#[doc = "`write(|w| ..)` method takes [mac_hashtable_low::W](mac_hashtable_low::W) writer structure"]
impl crate::Writable for MAC_HASHTABLE_LOW {}
#[doc = "Hash table low register"]
pub mod mac_hashtable_low;
#[doc = "MII address register\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [mac_mii_addr](mac_mii_addr) module"]
pub type MAC_MII_ADDR = crate::Reg<u32, _MAC_MII_ADDR>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _MAC_MII_ADDR;
#[doc = "`read()` method returns [mac_mii_addr::R](mac_mii_addr::R) reader structure"]
impl crate::Readable for MAC_MII_ADDR {}
#[doc = "`write(|w| ..)` method takes [mac_mii_addr::W](mac_mii_addr::W) writer structure"]
impl crate::Writable for MAC_MII_ADDR {}
#[doc = "MII address register"]
pub mod mac_mii_addr;
#[doc = "MII data register\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [mac_mii_data](mac_mii_data) module"]
pub type MAC_MII_DATA = crate::Reg<u32, _MAC_MII_DATA>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _MAC_MII_DATA;
#[doc = "`read()` method returns [mac_mii_data::R](mac_mii_data::R) reader structure"]
impl crate::Readable for MAC_MII_DATA {}
#[doc = "`write(|w| ..)` method takes [mac_mii_data::W](mac_mii_data::W) writer structure"]
impl crate::Writable for MAC_MII_DATA {}
#[doc = "MII data register"]
pub mod mac_mii_data;
#[doc = "Flow control register\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [mac_flow_ctrl](mac_flow_ctrl) module"]
pub type MAC_FLOW_CTRL = crate::Reg<u32, _MAC_FLOW_CTRL>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _MAC_FLOW_CTRL;
#[doc = "`read()` method returns [mac_flow_ctrl::R](mac_flow_ctrl::R) reader structure"]
impl crate::Readable for MAC_FLOW_CTRL {}
#[doc = "`write(|w| ..)` method takes [mac_flow_ctrl::W](mac_flow_ctrl::W) writer structure"]
impl crate::Writable for MAC_FLOW_CTRL {}
#[doc = "Flow control register"]
pub mod mac_flow_ctrl;
#[doc = "VLAN tag register\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [mac_vlan_tag](mac_vlan_tag) module"]
pub type MAC_VLAN_TAG = crate::Reg<u32, _MAC_VLAN_TAG>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _MAC_VLAN_TAG;
#[doc = "`read()` method returns [mac_vlan_tag::R](mac_vlan_tag::R) reader structure"]
impl crate::Readable for MAC_VLAN_TAG {}
#[doc = "`write(|w| ..)` method takes [mac_vlan_tag::W](mac_vlan_tag::W) writer structure"]
impl crate::Writable for MAC_VLAN_TAG {}
#[doc = "VLAN tag register"]
pub mod mac_vlan_tag;
#[doc = "Debug register\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [mac_debug](mac_debug) module"]
pub type MAC_DEBUG = crate::Reg<u32, _MAC_DEBUG>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _MAC_DEBUG;
#[doc = "`read()` method returns [mac_debug::R](mac_debug::R) reader structure"]
impl crate::Readable for MAC_DEBUG {}
#[doc = "Debug register"]
pub mod mac_debug;
#[doc = "Remote wake-up frame filter\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [mac_rwake_frflt](mac_rwake_frflt) module"]
pub type MAC_RWAKE_FRFLT = crate::Reg<u32, _MAC_RWAKE_FRFLT>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _MAC_RWAKE_FRFLT;
#[doc = "`read()` method returns [mac_rwake_frflt::R](mac_rwake_frflt::R) reader structure"]
impl crate::Readable for MAC_RWAKE_FRFLT {}
#[doc = "`write(|w| ..)` method takes [mac_rwake_frflt::W](mac_rwake_frflt::W) writer structure"]
impl crate::Writable for MAC_RWAKE_FRFLT {}
#[doc = "Remote wake-up frame filter"]
pub mod mac_rwake_frflt;
#[doc = "PMT control and status\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [mac_pmt_ctrl_stat](mac_pmt_ctrl_stat) module"]
pub type MAC_PMT_CTRL_STAT = crate::Reg<u32, _MAC_PMT_CTRL_STAT>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _MAC_PMT_CTRL_STAT;
#[doc = "`read()` method returns [mac_pmt_ctrl_stat::R](mac_pmt_ctrl_stat::R) reader structure"]
impl crate::Readable for MAC_PMT_CTRL_STAT {}
#[doc = "`write(|w| ..)` method takes [mac_pmt_ctrl_stat::W](mac_pmt_ctrl_stat::W) writer structure"]
impl crate::Writable for MAC_PMT_CTRL_STAT {}
#[doc = "PMT control and status"]
pub mod mac_pmt_ctrl_stat;
#[doc = "Interrupt status register\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [mac_intr](mac_intr) module"]
pub type MAC_INTR = crate::Reg<u32, _MAC_INTR>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _MAC_INTR;
#[doc = "`read()` method returns [mac_intr::R](mac_intr::R) reader structure"]
impl crate::Readable for MAC_INTR {}
#[doc = "Interrupt status register"]
pub mod mac_intr;
#[doc = "Interrupt mask register\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [mac_intr_mask](mac_intr_mask) module"]
pub type MAC_INTR_MASK = crate::Reg<u32, _MAC_INTR_MASK>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _MAC_INTR_MASK;
#[doc = "`read()` method returns [mac_intr_mask::R](mac_intr_mask::R) reader structure"]
impl crate::Readable for MAC_INTR_MASK {}
#[doc = "`write(|w| ..)` method takes [mac_intr_mask::W](mac_intr_mask::W) writer structure"]
impl crate::Writable for MAC_INTR_MASK {}
#[doc = "Interrupt mask register"]
pub mod mac_intr_mask;
#[doc = "MAC address 0 high register\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [mac_addr0_high](mac_addr0_high) module"]
pub type MAC_ADDR0_HIGH = crate::Reg<u32, _MAC_ADDR0_HIGH>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _MAC_ADDR0_HIGH;
#[doc = "`read()` method returns [mac_addr0_high::R](mac_addr0_high::R) reader structure"]
impl crate::Readable for MAC_ADDR0_HIGH {}
#[doc = "`write(|w| ..)` method takes [mac_addr0_high::W](mac_addr0_high::W) writer structure"]
impl crate::Writable for MAC_ADDR0_HIGH {}
#[doc = "MAC address 0 high register"]
pub mod mac_addr0_high;
#[doc = "MAC address 0 low register\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [mac_addr0_low](mac_addr0_low) module"]
pub type MAC_ADDR0_LOW = crate::Reg<u32, _MAC_ADDR0_LOW>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _MAC_ADDR0_LOW;
#[doc = "`read()` method returns [mac_addr0_low::R](mac_addr0_low::R) reader structure"]
impl crate::Readable for MAC_ADDR0_LOW {}
#[doc = "`write(|w| ..)` method takes [mac_addr0_low::W](mac_addr0_low::W) writer structure"]
impl crate::Writable for MAC_ADDR0_LOW {}
#[doc = "MAC address 0 low register"]
pub mod mac_addr0_low;
#[doc = "Time stamp control register\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [mac_timestp_ctrl](mac_timestp_ctrl) module"]
pub type MAC_TIMESTP_CTRL = crate::Reg<u32, _MAC_TIMESTP_CTRL>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _MAC_TIMESTP_CTRL;
#[doc = "`read()` method returns [mac_timestp_ctrl::R](mac_timestp_ctrl::R) reader structure"]
impl crate::Readable for MAC_TIMESTP_CTRL {}
#[doc = "`write(|w| ..)` method takes [mac_timestp_ctrl::W](mac_timestp_ctrl::W) writer structure"]
impl crate::Writable for MAC_TIMESTP_CTRL {}
#[doc = "Time stamp control register"]
pub mod mac_timestp_ctrl;
#[doc = "Sub-second increment register\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [subsecond_incr](subsecond_incr) module"]
pub type SUBSECOND_INCR = crate::Reg<u32, _SUBSECOND_INCR>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _SUBSECOND_INCR;
#[doc = "`read()` method returns [subsecond_incr::R](subsecond_incr::R) reader structure"]
impl crate::Readable for SUBSECOND_INCR {}
#[doc = "`write(|w| ..)` method takes [subsecond_incr::W](subsecond_incr::W) writer structure"]
impl crate::Writable for SUBSECOND_INCR {}
#[doc = "Sub-second increment register"]
pub mod subsecond_incr;
#[doc = "System time seconds register\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [seconds](seconds) module"]
pub type SECONDS = crate::Reg<u32, _SECONDS>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _SECONDS;
#[doc = "`read()` method returns [seconds::R](seconds::R) reader structure"]
impl crate::Readable for SECONDS {}
#[doc = "System time seconds register"]
pub mod seconds;
#[doc = "System time nanoseconds register\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [nanoseconds](nanoseconds) module"]
pub type NANOSECONDS = crate::Reg<u32, _NANOSECONDS>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _NANOSECONDS;
#[doc = "`read()` method returns [nanoseconds::R](nanoseconds::R) reader structure"]
impl crate::Readable for NANOSECONDS {}
#[doc = "System time nanoseconds register"]
pub mod nanoseconds;
#[doc = "System time seconds update register\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [secondsupdate](secondsupdate) module"]
pub type SECONDSUPDATE = crate::Reg<u32, _SECONDSUPDATE>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _SECONDSUPDATE;
#[doc = "`read()` method returns [secondsupdate::R](secondsupdate::R) reader structure"]
impl crate::Readable for SECONDSUPDATE {}
#[doc = "`write(|w| ..)` method takes [secondsupdate::W](secondsupdate::W) writer structure"]
impl crate::Writable for SECONDSUPDATE {}
#[doc = "System time seconds update register"]
pub mod secondsupdate;
#[doc = "System time nanoseconds update register\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [nanosecondsupdate](nanosecondsupdate) module"]
pub type NANOSECONDSUPDATE = crate::Reg<u32, _NANOSECONDSUPDATE>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _NANOSECONDSUPDATE;
#[doc = "`read()` method returns [nanosecondsupdate::R](nanosecondsupdate::R) reader structure"]
impl crate::Readable for NANOSECONDSUPDATE {}
#[doc = "`write(|w| ..)` method takes [nanosecondsupdate::W](nanosecondsupdate::W) writer structure"]
impl crate::Writable for NANOSECONDSUPDATE {}
#[doc = "System time nanoseconds update register"]
pub mod nanosecondsupdate;
#[doc = "Time stamp addend register\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [addend](addend) module"]
pub type ADDEND = crate::Reg<u32, _ADDEND>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _ADDEND;
#[doc = "`read()` method returns [addend::R](addend::R) reader structure"]
impl crate::Readable for ADDEND {}
#[doc = "`write(|w| ..)` method takes [addend::W](addend::W) writer structure"]
impl crate::Writable for ADDEND {}
#[doc = "Time stamp addend register"]
pub mod addend;
#[doc = "Target time seconds register\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [targetseconds](targetseconds) module"]
pub type TARGETSECONDS = crate::Reg<u32, _TARGETSECONDS>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _TARGETSECONDS;
#[doc = "`read()` method returns [targetseconds::R](targetseconds::R) reader structure"]
impl crate::Readable for TARGETSECONDS {}
#[doc = "`write(|w| ..)` method takes [targetseconds::W](targetseconds::W) writer structure"]
impl crate::Writable for TARGETSECONDS {}
#[doc = "Target time seconds register"]
pub mod targetseconds;
#[doc = "Target time nanoseconds register\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [targetnanoseconds](targetnanoseconds) module"]
pub type TARGETNANOSECONDS = crate::Reg<u32, _TARGETNANOSECONDS>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _TARGETNANOSECONDS;
#[doc = "`read()` method returns [targetnanoseconds::R](targetnanoseconds::R) reader structure"]
impl crate::Readable for TARGETNANOSECONDS {}
#[doc = "`write(|w| ..)` method takes [targetnanoseconds::W](targetnanoseconds::W) writer structure"]
impl crate::Writable for TARGETNANOSECONDS {}
#[doc = "Target time nanoseconds register"]
pub mod targetnanoseconds;
#[doc = "System time higher word seconds register\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [highword](highword) module"]
pub type HIGHWORD = crate::Reg<u32, _HIGHWORD>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _HIGHWORD;
#[doc = "`read()` method returns [highword::R](highword::R) reader structure"]
impl crate::Readable for HIGHWORD {}
#[doc = "`write(|w| ..)` method takes [highword::W](highword::W) writer structure"]
impl crate::Writable for HIGHWORD {}
#[doc = "System time higher word seconds register"]
pub mod highword;
#[doc = "Time stamp status register\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [timestampstat](timestampstat) module"]
pub type TIMESTAMPSTAT = crate::Reg<u32, _TIMESTAMPSTAT>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _TIMESTAMPSTAT;
#[doc = "`read()` method returns [timestampstat::R](timestampstat::R) reader structure"]
impl crate::Readable for TIMESTAMPSTAT {}
#[doc = "Time stamp status register"]
pub mod timestampstat;
#[doc = "Bus Mode Register\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dma_bus_mode](dma_bus_mode) module"]
pub type DMA_BUS_MODE = crate::Reg<u32, _DMA_BUS_MODE>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _DMA_BUS_MODE;
#[doc = "`read()` method returns [dma_bus_mode::R](dma_bus_mode::R) reader structure"]
impl crate::Readable for DMA_BUS_MODE {}
#[doc = "`write(|w| ..)` method takes [dma_bus_mode::W](dma_bus_mode::W) writer structure"]
impl crate::Writable for DMA_BUS_MODE {}
#[doc = "Bus Mode Register"]
pub mod dma_bus_mode;
#[doc = "Transmit poll demand register\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dma_trans_poll_demand](dma_trans_poll_demand) module"]
pub type DMA_TRANS_POLL_DEMAND = crate::Reg<u32, _DMA_TRANS_POLL_DEMAND>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _DMA_TRANS_POLL_DEMAND;
#[doc = "`read()` method returns [dma_trans_poll_demand::R](dma_trans_poll_demand::R) reader structure"]
impl crate::Readable for DMA_TRANS_POLL_DEMAND {}
#[doc = "`write(|w| ..)` method takes [dma_trans_poll_demand::W](dma_trans_poll_demand::W) writer structure"]
impl crate::Writable for DMA_TRANS_POLL_DEMAND {}
#[doc = "Transmit poll demand register"]
pub mod dma_trans_poll_demand;
#[doc = "Receive poll demand register\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dma_rec_poll_demand](dma_rec_poll_demand) module"]
pub type DMA_REC_POLL_DEMAND = crate::Reg<u32, _DMA_REC_POLL_DEMAND>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _DMA_REC_POLL_DEMAND;
#[doc = "`read()` method returns [dma_rec_poll_demand::R](dma_rec_poll_demand::R) reader structure"]
impl crate::Readable for DMA_REC_POLL_DEMAND {}
#[doc = "`write(|w| ..)` method takes [dma_rec_poll_demand::W](dma_rec_poll_demand::W) writer structure"]
impl crate::Writable for DMA_REC_POLL_DEMAND {}
#[doc = "Receive poll demand register"]
pub mod dma_rec_poll_demand;
#[doc = "Receive descriptor list address register\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dma_rec_des_addr](dma_rec_des_addr) module"]
pub type DMA_REC_DES_ADDR = crate::Reg<u32, _DMA_REC_DES_ADDR>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _DMA_REC_DES_ADDR;
#[doc = "`read()` method returns [dma_rec_des_addr::R](dma_rec_des_addr::R) reader structure"]
impl crate::Readable for DMA_REC_DES_ADDR {}
#[doc = "`write(|w| ..)` method takes [dma_rec_des_addr::W](dma_rec_des_addr::W) writer structure"]
impl crate::Writable for DMA_REC_DES_ADDR {}
#[doc = "Receive descriptor list address register"]
pub mod dma_rec_des_addr;
#[doc = "Transmit descriptor list address register\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dma_trans_des_addr](dma_trans_des_addr) module"]
pub type DMA_TRANS_DES_ADDR = crate::Reg<u32, _DMA_TRANS_DES_ADDR>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _DMA_TRANS_DES_ADDR;
#[doc = "`read()` method returns [dma_trans_des_addr::R](dma_trans_des_addr::R) reader structure"]
impl crate::Readable for DMA_TRANS_DES_ADDR {}
#[doc = "`write(|w| ..)` method takes [dma_trans_des_addr::W](dma_trans_des_addr::W) writer structure"]
impl crate::Writable for DMA_TRANS_DES_ADDR {}
#[doc = "Transmit descriptor list address register"]
pub mod dma_trans_des_addr;
#[doc = "Status register\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dma_stat](dma_stat) module"]
pub type DMA_STAT = crate::Reg<u32, _DMA_STAT>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _DMA_STAT;
#[doc = "`read()` method returns [dma_stat::R](dma_stat::R) reader structure"]
impl crate::Readable for DMA_STAT {}
#[doc = "`write(|w| ..)` method takes [dma_stat::W](dma_stat::W) writer structure"]
impl crate::Writable for DMA_STAT {}
#[doc = "Status register"]
pub mod dma_stat;
#[doc = "Operation mode register\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dma_op_mode](dma_op_mode) module"]
pub type DMA_OP_MODE = crate::Reg<u32, _DMA_OP_MODE>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _DMA_OP_MODE;
#[doc = "`read()` method returns [dma_op_mode::R](dma_op_mode::R) reader structure"]
impl crate::Readable for DMA_OP_MODE {}
#[doc = "`write(|w| ..)` method takes [dma_op_mode::W](dma_op_mode::W) writer structure"]
impl crate::Writable for DMA_OP_MODE {}
#[doc = "Operation mode register"]
pub mod dma_op_mode;
#[doc = "Interrupt enable register\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dma_int_en](dma_int_en) module"]
pub type DMA_INT_EN = crate::Reg<u32, _DMA_INT_EN>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _DMA_INT_EN;
#[doc = "`read()` method returns [dma_int_en::R](dma_int_en::R) reader structure"]
impl crate::Readable for DMA_INT_EN {}
#[doc = "`write(|w| ..)` method takes [dma_int_en::W](dma_int_en::W) writer structure"]
impl crate::Writable for DMA_INT_EN {}
#[doc = "Interrupt enable register"]
pub mod dma_int_en;
#[doc = "Missed frame and buffer overflow register\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dma_mfrm_bufof](dma_mfrm_bufof) module"]
pub type DMA_MFRM_BUFOF = crate::Reg<u32, _DMA_MFRM_BUFOF>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _DMA_MFRM_BUFOF;
#[doc = "`read()` method returns [dma_mfrm_bufof::R](dma_mfrm_bufof::R) reader structure"]
impl crate::Readable for DMA_MFRM_BUFOF {}
#[doc = "Missed frame and buffer overflow register"]
pub mod dma_mfrm_bufof;
#[doc = "Receive interrupt watchdog timer register\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dma_rec_int_wdt](dma_rec_int_wdt) module"]
pub type DMA_REC_INT_WDT = crate::Reg<u32, _DMA_REC_INT_WDT>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _DMA_REC_INT_WDT;
#[doc = "`read()` method returns [dma_rec_int_wdt::R](dma_rec_int_wdt::R) reader structure"]
impl crate::Readable for DMA_REC_INT_WDT {}
#[doc = "`write(|w| ..)` method takes [dma_rec_int_wdt::W](dma_rec_int_wdt::W) writer structure"]
impl crate::Writable for DMA_REC_INT_WDT {}
#[doc = "Receive interrupt watchdog timer register"]
pub mod dma_rec_int_wdt;
#[doc = "Current host transmit descriptor register\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dma_curhost_trans_des](dma_curhost_trans_des) module"]
pub type DMA_CURHOST_TRANS_DES = crate::Reg<u32, _DMA_CURHOST_TRANS_DES>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _DMA_CURHOST_TRANS_DES;
#[doc = "`read()` method returns [dma_curhost_trans_des::R](dma_curhost_trans_des::R) reader structure"]
impl crate::Readable for DMA_CURHOST_TRANS_DES {}
#[doc = "Current host transmit descriptor register"]
pub mod dma_curhost_trans_des;
#[doc = "Current host receive descriptor register\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dma_curhost_rec_des](dma_curhost_rec_des) module"]
pub type DMA_CURHOST_REC_DES = crate::Reg<u32, _DMA_CURHOST_REC_DES>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _DMA_CURHOST_REC_DES;
#[doc = "`read()` method returns [dma_curhost_rec_des::R](dma_curhost_rec_des::R) reader structure"]
impl crate::Readable for DMA_CURHOST_REC_DES {}
#[doc = "Current host receive descriptor register"]
pub mod dma_curhost_rec_des;
#[doc = "Current host transmit buffer address register\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dma_curhost_trans_buf](dma_curhost_trans_buf) module"]
pub type DMA_CURHOST_TRANS_BUF = crate::Reg<u32, _DMA_CURHOST_TRANS_BUF>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _DMA_CURHOST_TRANS_BUF;
#[doc = "`read()` method returns [dma_curhost_trans_buf::R](dma_curhost_trans_buf::R) reader structure"]
impl crate::Readable for DMA_CURHOST_TRANS_BUF {}
#[doc = "Current host transmit buffer address register"]
pub mod dma_curhost_trans_buf;
#[doc = "Current host receive buffer address register\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dma_curhost_rec_buf](dma_curhost_rec_buf) module"]
pub type DMA_CURHOST_REC_BUF = crate::Reg<u32, _DMA_CURHOST_REC_BUF>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _DMA_CURHOST_REC_BUF;
#[doc = "`read()` method returns [dma_curhost_rec_buf::R](dma_curhost_rec_buf::R) reader structure"]
impl crate::Readable for DMA_CURHOST_REC_BUF {}
#[doc = "Current host receive buffer address register"]
pub mod dma_curhost_rec_buf;
