#[doc = r"Register block"]
#[repr(C)]
pub struct RegisterBlock {
    #[doc = "0x00 - Pin multiplexer configuration registers."]
    pub out_mux_cfg: [OUT_MUX_CFG; 16],
    #[doc = "0x40 - SGPIO multiplexer configuration registers."]
    pub sgpio_mux_cfg: [SGPIO_MUX_CFG; 16],
    #[doc = "0x80 - Slice multiplexer configuration registers."]
    pub slice_mux_cfg: [SLICE_MUX_CFG; 16],
    #[doc = "0xc0 - Slice data registers. Each time COUNT0 reaches 0x0 the register shifts loading bit 31 with data captured from DIN(n). DOUT(n) is set to REG(0)"]
    pub reg: [REG; 16],
    #[doc = "0x100 - Slice data shadow registers. Each time POS reaches 0x0 the contents of REG_SS is exchanged with the content of REG"]
    pub reg_ss: [REG_SS; 16],
    #[doc = "0x140 - Reload value of COUNT0, loaded when COUNT0 reaches 0x0"]
    pub preset: [PRESET; 16],
    #[doc = "0x180 - Down counter, counts down each clock cycle."]
    pub count: [COUNT; 16],
    #[doc = "0x1c0 - Each time COUNT0 reaches 0x0 POS counts down."]
    pub pos: [POS; 16],
    #[doc = "0x200 - Mask for pattern match function of slice A"]
    pub mask_a: MASK_A,
    #[doc = "0x204 - Mask for pattern match function of slice H"]
    pub mask_h: MASK_H,
    #[doc = "0x208 - Mask for pattern match function of slice I"]
    pub mask_i: MASK_I,
    #[doc = "0x20c - Mask for pattern match function of slice P"]
    pub mask_p: MASK_P,
    #[doc = "0x210 - GPIO input status register"]
    pub gpio_inreg: GPIO_INREG,
    #[doc = "0x214 - GPIO output control register"]
    pub gpio_outreg: GPIO_OUTREG,
    #[doc = "0x218 - GPIO OE control register"]
    pub gpio_oenreg: GPIO_OENREG,
    #[doc = "0x21c - Enables the slice COUNT counter"]
    pub ctrl_enable: CTRL_ENABLE,
    #[doc = "0x220 - Disables the slice POS counter"]
    pub ctrl_disable: CTRL_DISABLE,
    _reserved17: [u8; 3292usize],
    #[doc = "0xf00 - Shift clock interrupt clear mask"]
    pub clr_en_0: CLR_EN_0,
    #[doc = "0xf04 - Shift clock interrupt set mask"]
    pub set_en_0: SET_EN_0,
    #[doc = "0xf08 - Shift clock interrupt enable"]
    pub enable_0: ENABLE_0,
    #[doc = "0xf0c - Shift clock interrupt status"]
    pub status_0: STATUS_0,
    #[doc = "0xf10 - Shift clock interrupt clear status"]
    pub clr_status_0: CLR_STATUS_0,
    #[doc = "0xf14 - Shift clock interrupt set status"]
    pub set_status_0: SET_STATUS_0,
    _reserved23: [u8; 8usize],
    #[doc = "0xf20 - Exchange clock interrupt clear mask"]
    pub clr_en_1: CLR_EN_1,
    #[doc = "0xf24 - Exchange clock interrupt set mask"]
    pub set_en_1: SET_EN_1,
    #[doc = "0xf28 - Exchange clock interrupt enable"]
    pub enable_1: ENABLE_1,
    #[doc = "0xf2c - Exchange clock interrupt status"]
    pub status_1: STATUS_1,
    #[doc = "0xf30 - Exchange clock interrupt clear status"]
    pub clr_status_1: CLR_STATUS_1,
    #[doc = "0xf34 - Exchange clock interrupt set status"]
    pub set_status_1: SET_STATUS_1,
    _reserved29: [u8; 8usize],
    #[doc = "0xf40 - Pattern match interrupt clear mask"]
    pub clr_en_2: CLR_EN_2,
    #[doc = "0xf44 - Pattern match interrupt set mask"]
    pub set_en_2: SET_EN_2,
    #[doc = "0xf48 - Pattern match interrupt enable"]
    pub enable_2: ENABLE_2,
    #[doc = "0xf4c - Pattern match interrupt status"]
    pub status_2: STATUS_2,
    #[doc = "0xf50 - Pattern match interrupt clear status"]
    pub clr_status_2: CLR_STATUS_2,
    #[doc = "0xf54 - Pattern match interrupt set status"]
    pub set_status_2: SET_STATUS_2,
    _reserved35: [u8; 8usize],
    #[doc = "0xf60 - Input interrupt clear mask"]
    pub clr_en_3: CLR_EN_3,
    #[doc = "0xf64 - Input bit match interrupt set mask"]
    pub set_en_3: SET_EN_3,
    #[doc = "0xf68 - Input bit match interrupt enable"]
    pub enable_3: ENABLE_3,
    #[doc = "0xf6c - Input bit match interrupt status"]
    pub status_3: STATUS_3,
    #[doc = "0xf70 - Input bit match interrupt clear status"]
    pub clr_status_3: CLR_STATUS_3,
    #[doc = "0xf74 - Input bit match interrupt set status"]
    pub set_status_3: SET_STATUS_3,
}
#[doc = "Pin multiplexer configuration registers.\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [out_mux_cfg](out_mux_cfg) module"]
pub type OUT_MUX_CFG = crate::Reg<u32, _OUT_MUX_CFG>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _OUT_MUX_CFG;
#[doc = "`read()` method returns [out_mux_cfg::R](out_mux_cfg::R) reader structure"]
impl crate::Readable for OUT_MUX_CFG {}
#[doc = "`write(|w| ..)` method takes [out_mux_cfg::W](out_mux_cfg::W) writer structure"]
impl crate::Writable for OUT_MUX_CFG {}
#[doc = "Pin multiplexer configuration registers."]
pub mod out_mux_cfg;
#[doc = "SGPIO multiplexer configuration registers.\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [sgpio_mux_cfg](sgpio_mux_cfg) module"]
pub type SGPIO_MUX_CFG = crate::Reg<u32, _SGPIO_MUX_CFG>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _SGPIO_MUX_CFG;
#[doc = "`read()` method returns [sgpio_mux_cfg::R](sgpio_mux_cfg::R) reader structure"]
impl crate::Readable for SGPIO_MUX_CFG {}
#[doc = "`write(|w| ..)` method takes [sgpio_mux_cfg::W](sgpio_mux_cfg::W) writer structure"]
impl crate::Writable for SGPIO_MUX_CFG {}
#[doc = "SGPIO multiplexer configuration registers."]
pub mod sgpio_mux_cfg;
#[doc = "Slice multiplexer configuration registers.\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [slice_mux_cfg](slice_mux_cfg) module"]
pub type SLICE_MUX_CFG = crate::Reg<u32, _SLICE_MUX_CFG>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _SLICE_MUX_CFG;
#[doc = "`read()` method returns [slice_mux_cfg::R](slice_mux_cfg::R) reader structure"]
impl crate::Readable for SLICE_MUX_CFG {}
#[doc = "`write(|w| ..)` method takes [slice_mux_cfg::W](slice_mux_cfg::W) writer structure"]
impl crate::Writable for SLICE_MUX_CFG {}
#[doc = "Slice multiplexer configuration registers."]
pub mod slice_mux_cfg;
#[doc = "Slice data registers. Each time COUNT0 reaches 0x0 the register shifts loading bit 31 with data captured from DIN(n). DOUT(n) is set to REG(0)\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [reg](reg) module"]
pub type REG = crate::Reg<u32, _REG>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _REG;
#[doc = "`read()` method returns [reg::R](reg::R) reader structure"]
impl crate::Readable for REG {}
#[doc = "`write(|w| ..)` method takes [reg::W](reg::W) writer structure"]
impl crate::Writable for REG {}
#[doc = "Slice data registers. Each time COUNT0 reaches 0x0 the register shifts loading bit 31 with data captured from DIN(n). DOUT(n) is set to REG(0)"]
pub mod reg;
#[doc = "Slice data shadow registers. Each time POS reaches 0x0 the contents of REG_SS is exchanged with the content of REG\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [reg_ss](reg_ss) module"]
pub type REG_SS = crate::Reg<u32, _REG_SS>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _REG_SS;
#[doc = "`read()` method returns [reg_ss::R](reg_ss::R) reader structure"]
impl crate::Readable for REG_SS {}
#[doc = "`write(|w| ..)` method takes [reg_ss::W](reg_ss::W) writer structure"]
impl crate::Writable for REG_SS {}
#[doc = "Slice data shadow registers. Each time POS reaches 0x0 the contents of REG_SS is exchanged with the content of REG"]
pub mod reg_ss;
#[doc = "Reload value of COUNT0, loaded when COUNT0 reaches 0x0\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [preset](preset) module"]
pub type PRESET = crate::Reg<u32, _PRESET>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _PRESET;
#[doc = "`read()` method returns [preset::R](preset::R) reader structure"]
impl crate::Readable for PRESET {}
#[doc = "`write(|w| ..)` method takes [preset::W](preset::W) writer structure"]
impl crate::Writable for PRESET {}
#[doc = "Reload value of COUNT0, loaded when COUNT0 reaches 0x0"]
pub mod preset;
#[doc = "Down counter, counts down each clock cycle.\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [count](count) module"]
pub type COUNT = crate::Reg<u32, _COUNT>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _COUNT;
#[doc = "`read()` method returns [count::R](count::R) reader structure"]
impl crate::Readable for COUNT {}
#[doc = "`write(|w| ..)` method takes [count::W](count::W) writer structure"]
impl crate::Writable for COUNT {}
#[doc = "Down counter, counts down each clock cycle."]
pub mod count;
#[doc = "Each time COUNT0 reaches 0x0 POS counts down.\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [pos](pos) module"]
pub type POS = crate::Reg<u32, _POS>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _POS;
#[doc = "`read()` method returns [pos::R](pos::R) reader structure"]
impl crate::Readable for POS {}
#[doc = "`write(|w| ..)` method takes [pos::W](pos::W) writer structure"]
impl crate::Writable for POS {}
#[doc = "Each time COUNT0 reaches 0x0 POS counts down."]
pub mod pos;
#[doc = "Mask for pattern match function of slice A\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [mask_a](mask_a) module"]
pub type MASK_A = crate::Reg<u32, _MASK_A>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _MASK_A;
#[doc = "`read()` method returns [mask_a::R](mask_a::R) reader structure"]
impl crate::Readable for MASK_A {}
#[doc = "`write(|w| ..)` method takes [mask_a::W](mask_a::W) writer structure"]
impl crate::Writable for MASK_A {}
#[doc = "Mask for pattern match function of slice A"]
pub mod mask_a;
#[doc = "Mask for pattern match function of slice H\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [mask_h](mask_h) module"]
pub type MASK_H = crate::Reg<u32, _MASK_H>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _MASK_H;
#[doc = "`read()` method returns [mask_h::R](mask_h::R) reader structure"]
impl crate::Readable for MASK_H {}
#[doc = "`write(|w| ..)` method takes [mask_h::W](mask_h::W) writer structure"]
impl crate::Writable for MASK_H {}
#[doc = "Mask for pattern match function of slice H"]
pub mod mask_h;
#[doc = "Mask for pattern match function of slice I\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [mask_i](mask_i) module"]
pub type MASK_I = crate::Reg<u32, _MASK_I>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _MASK_I;
#[doc = "`read()` method returns [mask_i::R](mask_i::R) reader structure"]
impl crate::Readable for MASK_I {}
#[doc = "`write(|w| ..)` method takes [mask_i::W](mask_i::W) writer structure"]
impl crate::Writable for MASK_I {}
#[doc = "Mask for pattern match function of slice I"]
pub mod mask_i;
#[doc = "Mask for pattern match function of slice P\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [mask_p](mask_p) module"]
pub type MASK_P = crate::Reg<u32, _MASK_P>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _MASK_P;
#[doc = "`read()` method returns [mask_p::R](mask_p::R) reader structure"]
impl crate::Readable for MASK_P {}
#[doc = "`write(|w| ..)` method takes [mask_p::W](mask_p::W) writer structure"]
impl crate::Writable for MASK_P {}
#[doc = "Mask for pattern match function of slice P"]
pub mod mask_p;
#[doc = "GPIO input status register\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [gpio_inreg](gpio_inreg) module"]
pub type GPIO_INREG = crate::Reg<u32, _GPIO_INREG>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _GPIO_INREG;
#[doc = "`read()` method returns [gpio_inreg::R](gpio_inreg::R) reader structure"]
impl crate::Readable for GPIO_INREG {}
#[doc = "GPIO input status register"]
pub mod gpio_inreg;
#[doc = "GPIO output control register\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [gpio_outreg](gpio_outreg) module"]
pub type GPIO_OUTREG = crate::Reg<u32, _GPIO_OUTREG>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _GPIO_OUTREG;
#[doc = "`read()` method returns [gpio_outreg::R](gpio_outreg::R) reader structure"]
impl crate::Readable for GPIO_OUTREG {}
#[doc = "`write(|w| ..)` method takes [gpio_outreg::W](gpio_outreg::W) writer structure"]
impl crate::Writable for GPIO_OUTREG {}
#[doc = "GPIO output control register"]
pub mod gpio_outreg;
#[doc = "GPIO OE control register\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [gpio_oenreg](gpio_oenreg) module"]
pub type GPIO_OENREG = crate::Reg<u32, _GPIO_OENREG>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _GPIO_OENREG;
#[doc = "`read()` method returns [gpio_oenreg::R](gpio_oenreg::R) reader structure"]
impl crate::Readable for GPIO_OENREG {}
#[doc = "`write(|w| ..)` method takes [gpio_oenreg::W](gpio_oenreg::W) writer structure"]
impl crate::Writable for GPIO_OENREG {}
#[doc = "GPIO OE control register"]
pub mod gpio_oenreg;
#[doc = "Enables the slice COUNT counter\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [ctrl_enable](ctrl_enable) module"]
pub type CTRL_ENABLE = crate::Reg<u32, _CTRL_ENABLE>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _CTRL_ENABLE;
#[doc = "`read()` method returns [ctrl_enable::R](ctrl_enable::R) reader structure"]
impl crate::Readable for CTRL_ENABLE {}
#[doc = "`write(|w| ..)` method takes [ctrl_enable::W](ctrl_enable::W) writer structure"]
impl crate::Writable for CTRL_ENABLE {}
#[doc = "Enables the slice COUNT counter"]
pub mod ctrl_enable;
#[doc = "Disables the slice POS counter\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [ctrl_disable](ctrl_disable) module"]
pub type CTRL_DISABLE = crate::Reg<u32, _CTRL_DISABLE>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _CTRL_DISABLE;
#[doc = "`read()` method returns [ctrl_disable::R](ctrl_disable::R) reader structure"]
impl crate::Readable for CTRL_DISABLE {}
#[doc = "`write(|w| ..)` method takes [ctrl_disable::W](ctrl_disable::W) writer structure"]
impl crate::Writable for CTRL_DISABLE {}
#[doc = "Disables the slice POS counter"]
pub mod ctrl_disable;
#[doc = "Shift clock interrupt clear mask\n\nThis register you can [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [clr_en_0](clr_en_0) module"]
pub type CLR_EN_0 = crate::Reg<u32, _CLR_EN_0>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _CLR_EN_0;
#[doc = "`write(|w| ..)` method takes [clr_en_0::W](clr_en_0::W) writer structure"]
impl crate::Writable for CLR_EN_0 {}
#[doc = "Shift clock interrupt clear mask"]
pub mod clr_en_0;
#[doc = "Shift clock interrupt set mask\n\nThis register you can [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [set_en_0](set_en_0) module"]
pub type SET_EN_0 = crate::Reg<u32, _SET_EN_0>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _SET_EN_0;
#[doc = "`write(|w| ..)` method takes [set_en_0::W](set_en_0::W) writer structure"]
impl crate::Writable for SET_EN_0 {}
#[doc = "Shift clock interrupt set mask"]
pub mod set_en_0;
#[doc = "Shift clock interrupt enable\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [enable_0](enable_0) module"]
pub type ENABLE_0 = crate::Reg<u32, _ENABLE_0>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _ENABLE_0;
#[doc = "`read()` method returns [enable_0::R](enable_0::R) reader structure"]
impl crate::Readable for ENABLE_0 {}
#[doc = "Shift clock interrupt enable"]
pub mod enable_0;
#[doc = "Shift clock interrupt status\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [status_0](status_0) module"]
pub type STATUS_0 = crate::Reg<u32, _STATUS_0>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _STATUS_0;
#[doc = "`read()` method returns [status_0::R](status_0::R) reader structure"]
impl crate::Readable for STATUS_0 {}
#[doc = "Shift clock interrupt status"]
pub mod status_0;
#[doc = "Shift clock interrupt clear status\n\nThis register you can [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [clr_status_0](clr_status_0) module"]
pub type CLR_STATUS_0 = crate::Reg<u32, _CLR_STATUS_0>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _CLR_STATUS_0;
#[doc = "`write(|w| ..)` method takes [clr_status_0::W](clr_status_0::W) writer structure"]
impl crate::Writable for CLR_STATUS_0 {}
#[doc = "Shift clock interrupt clear status"]
pub mod clr_status_0;
#[doc = "Shift clock interrupt set status\n\nThis register you can [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [set_status_0](set_status_0) module"]
pub type SET_STATUS_0 = crate::Reg<u32, _SET_STATUS_0>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _SET_STATUS_0;
#[doc = "`write(|w| ..)` method takes [set_status_0::W](set_status_0::W) writer structure"]
impl crate::Writable for SET_STATUS_0 {}
#[doc = "Shift clock interrupt set status"]
pub mod set_status_0;
#[doc = "Exchange clock interrupt clear mask\n\nThis register you can [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [clr_en_1](clr_en_1) module"]
pub type CLR_EN_1 = crate::Reg<u32, _CLR_EN_1>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _CLR_EN_1;
#[doc = "`write(|w| ..)` method takes [clr_en_1::W](clr_en_1::W) writer structure"]
impl crate::Writable for CLR_EN_1 {}
#[doc = "Exchange clock interrupt clear mask"]
pub mod clr_en_1;
#[doc = "Exchange clock interrupt set mask\n\nThis register you can [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [set_en_1](set_en_1) module"]
pub type SET_EN_1 = crate::Reg<u32, _SET_EN_1>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _SET_EN_1;
#[doc = "`write(|w| ..)` method takes [set_en_1::W](set_en_1::W) writer structure"]
impl crate::Writable for SET_EN_1 {}
#[doc = "Exchange clock interrupt set mask"]
pub mod set_en_1;
#[doc = "Exchange clock interrupt enable\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [enable_1](enable_1) module"]
pub type ENABLE_1 = crate::Reg<u32, _ENABLE_1>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _ENABLE_1;
#[doc = "`read()` method returns [enable_1::R](enable_1::R) reader structure"]
impl crate::Readable for ENABLE_1 {}
#[doc = "Exchange clock interrupt enable"]
pub mod enable_1;
#[doc = "Exchange clock interrupt status\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [status_1](status_1) module"]
pub type STATUS_1 = crate::Reg<u32, _STATUS_1>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _STATUS_1;
#[doc = "`read()` method returns [status_1::R](status_1::R) reader structure"]
impl crate::Readable for STATUS_1 {}
#[doc = "Exchange clock interrupt status"]
pub mod status_1;
#[doc = "Exchange clock interrupt clear status\n\nThis register you can [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [clr_status_1](clr_status_1) module"]
pub type CLR_STATUS_1 = crate::Reg<u32, _CLR_STATUS_1>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _CLR_STATUS_1;
#[doc = "`write(|w| ..)` method takes [clr_status_1::W](clr_status_1::W) writer structure"]
impl crate::Writable for CLR_STATUS_1 {}
#[doc = "Exchange clock interrupt clear status"]
pub mod clr_status_1;
#[doc = "Exchange clock interrupt set status\n\nThis register you can [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [set_status_1](set_status_1) module"]
pub type SET_STATUS_1 = crate::Reg<u32, _SET_STATUS_1>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _SET_STATUS_1;
#[doc = "`write(|w| ..)` method takes [set_status_1::W](set_status_1::W) writer structure"]
impl crate::Writable for SET_STATUS_1 {}
#[doc = "Exchange clock interrupt set status"]
pub mod set_status_1;
#[doc = "Pattern match interrupt clear mask\n\nThis register you can [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [clr_en_2](clr_en_2) module"]
pub type CLR_EN_2 = crate::Reg<u32, _CLR_EN_2>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _CLR_EN_2;
#[doc = "`write(|w| ..)` method takes [clr_en_2::W](clr_en_2::W) writer structure"]
impl crate::Writable for CLR_EN_2 {}
#[doc = "Pattern match interrupt clear mask"]
pub mod clr_en_2;
#[doc = "Pattern match interrupt set mask\n\nThis register you can [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [set_en_2](set_en_2) module"]
pub type SET_EN_2 = crate::Reg<u32, _SET_EN_2>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _SET_EN_2;
#[doc = "`write(|w| ..)` method takes [set_en_2::W](set_en_2::W) writer structure"]
impl crate::Writable for SET_EN_2 {}
#[doc = "Pattern match interrupt set mask"]
pub mod set_en_2;
#[doc = "Pattern match interrupt enable\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [enable_2](enable_2) module"]
pub type ENABLE_2 = crate::Reg<u32, _ENABLE_2>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _ENABLE_2;
#[doc = "`read()` method returns [enable_2::R](enable_2::R) reader structure"]
impl crate::Readable for ENABLE_2 {}
#[doc = "Pattern match interrupt enable"]
pub mod enable_2;
#[doc = "Pattern match interrupt status\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [status_2](status_2) module"]
pub type STATUS_2 = crate::Reg<u32, _STATUS_2>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _STATUS_2;
#[doc = "`read()` method returns [status_2::R](status_2::R) reader structure"]
impl crate::Readable for STATUS_2 {}
#[doc = "Pattern match interrupt status"]
pub mod status_2;
#[doc = "Pattern match interrupt clear status\n\nThis register you can [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [clr_status_2](clr_status_2) module"]
pub type CLR_STATUS_2 = crate::Reg<u32, _CLR_STATUS_2>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _CLR_STATUS_2;
#[doc = "`write(|w| ..)` method takes [clr_status_2::W](clr_status_2::W) writer structure"]
impl crate::Writable for CLR_STATUS_2 {}
#[doc = "Pattern match interrupt clear status"]
pub mod clr_status_2;
#[doc = "Pattern match interrupt set status\n\nThis register you can [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [set_status_2](set_status_2) module"]
pub type SET_STATUS_2 = crate::Reg<u32, _SET_STATUS_2>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _SET_STATUS_2;
#[doc = "`write(|w| ..)` method takes [set_status_2::W](set_status_2::W) writer structure"]
impl crate::Writable for SET_STATUS_2 {}
#[doc = "Pattern match interrupt set status"]
pub mod set_status_2;
#[doc = "Input interrupt clear mask\n\nThis register you can [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [clr_en_3](clr_en_3) module"]
pub type CLR_EN_3 = crate::Reg<u32, _CLR_EN_3>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _CLR_EN_3;
#[doc = "`write(|w| ..)` method takes [clr_en_3::W](clr_en_3::W) writer structure"]
impl crate::Writable for CLR_EN_3 {}
#[doc = "Input interrupt clear mask"]
pub mod clr_en_3;
#[doc = "Input bit match interrupt set mask\n\nThis register you can [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [set_en_3](set_en_3) module"]
pub type SET_EN_3 = crate::Reg<u32, _SET_EN_3>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _SET_EN_3;
#[doc = "`write(|w| ..)` method takes [set_en_3::W](set_en_3::W) writer structure"]
impl crate::Writable for SET_EN_3 {}
#[doc = "Input bit match interrupt set mask"]
pub mod set_en_3;
#[doc = "Input bit match interrupt enable\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [enable_3](enable_3) module"]
pub type ENABLE_3 = crate::Reg<u32, _ENABLE_3>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _ENABLE_3;
#[doc = "`read()` method returns [enable_3::R](enable_3::R) reader structure"]
impl crate::Readable for ENABLE_3 {}
#[doc = "Input bit match interrupt enable"]
pub mod enable_3;
#[doc = "Input bit match interrupt status\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [status_3](status_3) module"]
pub type STATUS_3 = crate::Reg<u32, _STATUS_3>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _STATUS_3;
#[doc = "`read()` method returns [status_3::R](status_3::R) reader structure"]
impl crate::Readable for STATUS_3 {}
#[doc = "Input bit match interrupt status"]
pub mod status_3;
#[doc = "Input bit match interrupt clear status\n\nThis register you can [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [clr_status_3](clr_status_3) module"]
pub type CLR_STATUS_3 = crate::Reg<u32, _CLR_STATUS_3>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _CLR_STATUS_3;
#[doc = "`write(|w| ..)` method takes [clr_status_3::W](clr_status_3::W) writer structure"]
impl crate::Writable for CLR_STATUS_3 {}
#[doc = "Input bit match interrupt clear status"]
pub mod clr_status_3;
#[doc = "Input bit match interrupt set status\n\nThis register you can [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [set_status_3](set_status_3) module"]
pub type SET_STATUS_3 = crate::Reg<u32, _SET_STATUS_3>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _SET_STATUS_3;
#[doc = "`write(|w| ..)` method takes [set_status_3::W](set_status_3::W) writer structure"]
impl crate::Writable for SET_STATUS_3 {}
#[doc = "Input bit match interrupt set status"]
pub mod set_status_3;
